Py-Search Package 
=================

Base
----

.. automodule:: py_search.base
    :members:
    :undoc-members:
    :show-inheritance:

Uninformed Search
-----------------

.. automodule:: py_search.uninformed
    :members:
    :undoc-members:
    :show-inheritance:

Informed Search
---------------

.. automodule:: py_search.informed
    :members:
    :undoc-members:
    :show-inheritance:

Optimization / Local Search
---------------------------

.. automodule:: py_search.optimization
    :members:
    :undoc-members:
    :show-inheritance:
